import { BaseLLMProvider } from './shared/baseProvider';
import { LLMProvider } from '../constants/llmProvider';
import { RequestPayload } from '../models/payloads';
import { ToolResponse } from '../models/toolResponse';
import { IBedrockTool } from '../types';
/**
 * @class AmazonBedrockSupportedModels
 * @description A class containing constants representing various supported models in Amazon Bedrock.
 */
export declare abstract class AmazonBedrockSupportedModels {
    /**
     * @constant
     * @type {string}
     * @description Anthropocene Claude 3 Haiku model with a version date of 2024-03-07.
     */
    static readonly ANTHROPIC_CLAUDE_3_HAIKU_20240307 = "anthropic.claude-3-haiku-20240307-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Anthropocene Claude 3.5 Sonnet model with a version date of 2024-06-20.
     */
    static readonly ANTHROPIC_CLAUDE_3_5_SONNET_20240620 = "anthropic.claude-3-5-sonnet-20240620-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Cohere Command R model.
     */
    static readonly COHERE_COMMAND_R = "cohere.command-r-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Cohere Command R Plus model.
     */
    static readonly COHERE_COMMAND_R_PLUS = "cohere.command-r-plus-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Meta Llama 3 1.8B Instruct model.
     */
    static readonly META_LLAMA3_1_8B_INSTRUCT = "meta.llama3-1-8b-instruct-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Meta Llama 3 1.70B Instruct model.
     */
    static readonly META_LLAMA3_1_70B_INSTRUCT = "meta.llama3-1-70b-instruct-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Meta Llama 3 1.405B Instruct model.
     */
    static readonly META_LLAMA3_1_405B_INSTRUCT = "meta.llama3-1-405b-instruct-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Mistral Large 2402 model.
     */
    static readonly MISTRAL_MISTRAL_LARGE_2402 = "mistral.mistral-large-2402-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Mistral Large 2407 model.
     */
    static readonly MISTRAL_MISTRAL_LARGE_2407 = "mistral.mistral-large-2407-v1:0";
    /**
     * @constant
     * @type {string}
     * @description Mistral Small 2402 model.
     */
    static readonly MISTRAL_MISTRAL_SMALL_2402 = "mistral.mistral-small-2402-v1:0";
}
/**
 * Class representing the Amazon Bedrock LLM provider.
 */
export declare class AmazonBedrock extends BaseLLMProvider {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Transforms a string to a valid AWS identifier.
     * @param inputString - The string to transform.
     * @returns The transformed string.
     */
    static transformToValidAWSIdentifier(inputString: string): string;
    toolsNamesMapping: Record<string, string>;
    /**
     * Checks if the tools have already been mapped.
     * @returns True if the tools have already been mapped, otherwise false.
     */
    get alreadyMappedFunctions(): boolean;
    /**
     * Post-processes the tools to conform to the IBedrockTool interface.
     * @param tools - The tools to post-process.
     * @returns An array of post-processed tools.
     */
    postProcessTools(tools: any[]): IBedrockTool[];
    /**
     * Invokes tools based on the tool selector response.
     * @param toolSelectorResponse - The response from the tool selector.
     * @returns An array of tool responses.
     * @throws Will throw an error if the tool selector response does not contain valid choices.
     */
    invokeTools(toolSelectorResponse: any): ToolResponse[];
    /**
     * Filters the tools to find the one with the specified ID.
     * @param toolId - The ID of the tool to find.
     * @returns An array containing the filtered tool, or an empty array if not found.
     */
    filterTool(toolId: string): any[];
    /**
     * Invokes a single tool with the given ID and payload.
     * @param toolId - The ID of the tool to invoke.
     * @param payload - The payload to pass to the tool.
     * @returns The result of the tool invocation.
     * @throws Will throw an error if the tool implementation is not found.
     */
    singleToolInvoke(toolId: string, payload: RequestPayload): string;
}
