import { LLMProvider } from '../../constants/llmProvider';
import { XpanderClient } from '../../core/XpanderClient';
import { RequestPayload } from '../../models/payloads';
import { ToolResponse } from '../../models/toolResponse';
/**
 * Class representing the base LLM provider.
 */
export declare class BaseLLMProvider {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    client: XpanderClient;
    /**
     * Constructs a new BaseLLMProvider instance.
     * @param xpanderClient - The XpanderClient instance.
     */
    constructor(xpanderClient: XpanderClient);
    /**
     * Retrieves the tools for the LLM provider.
     * @param functionize - (Optional) Whether to include an invocation function for the tools. Default is false.
     * @returns An array of tools.
     */
    getTools<T>(functionize?: boolean): T[];
    /**
     * Invokes a single tool with the given ID and payload.
     * @param toolId - The ID of the tool to invoke.
     * @param payload - The payload to pass to the tool.
     * @returns The result of the tool invocation.
     * @throws Will throw an error if the tool implementation is not found.
     */
    singleToolInvoke(toolId: string, payload: RequestPayload): string;
    /**
     * Invokes the tools based on the tool selector response.
     * @param toolSelectorResponse - The response from the tool selector.
     * @returns An array of tool responses.
     * @throws Will throw an error if the tool selector response does not contain valid choices.
     */
    invokeTools(toolSelectorResponse: any): ToolResponse[];
    /**
     * Filters the tools to find the one with the specified ID.
     * @param toolId - The ID of the tool to find.
     * @returns An array containing the filtered tool, or an empty array if not found.
     */
    filterTool(toolId: string): any[];
    /**
     * Post-processes the tools before returning them.
     * @param tools - The tools to post-process.
     * @returns The post-processed tools.
     */
    postProcessTools(tools: any[]): any[];
}
